Package: MSTest
Type: Package
Title: Hypothesis Testing for Markov Switching Models
Date: 2026-01-08
Version: 0.1.8
Authors@R: 
  c(person(given = "Gabriel", 
           family = "Rodriguez Rondon", 
           role = c("cre","aut"), 
           email = "gabriel.rodriguezrondon@mail.mcgill.ca",
           comment = c(ORCID = "0009-0005-3769-9921")),
    person(given = "Jean-Marie", 
           family = "Dufour", 
           role = c("aut"),
           email = "jean-marie.dufour@mcgill.ca"))
Maintainer: Gabriel Rodriguez Rondon <gabriel.rodriguezrondon@mail.mcgill.ca>
Description: Implementation of hypothesis testing procedures described in Hansen (1992) <doi:10.1002/jae.3950070506>, Carrasco, Hu, & Ploberger (2014) <doi:10.3982/ECTA8609>, Dufour & Luger (2017) <doi:10.1080/07474938.2017.1307548>, and Rodriguez Rondon & Dufour (2024) <https://grodriguezrondon.com/files/RodriguezRondon_Dufour_2025_MonteCarlo_LikelihoodRatioTest_MarkovSwitchingModels_20251014.pdf> that can be used to identify the number of regimes in Markov switching models.
License: GPL (>= 2)
LazyData: TRUE
RoxygenNote: 7.3.1
Encoding: UTF-8
URL: https://github.com/roga11/MSTest
BugReports: https://github.com/roga11/MSTest/issues
Imports: stats, rlang, nloptr, Rcpp (>= 1.0.1), numDeriv, pracma,
        foreach, GenSA, pso, GA, graphics
LinkingTo: Rcpp, RcppArmadillo
Depends: R (>= 4.0.0)
SystemRequirements: C++17
NeedsCompilation: yes
Packaged: 2026-01-09 15:05:53 UTC; gabrielrodriguez
Author: Gabriel Rodriguez Rondon [cre, aut] (ORCID:
    <https://orcid.org/0009-0005-3769-9921>),
  Jean-Marie Dufour [aut]
Repository: CRAN
Date/Publication: 2026-01-09 16:00:14 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 11:08:10 UTC; unix
Archs: MSTest.so.dSYM
