# Generated by roxygen2: do not edit by hand

S3method(AIC,ARmdl)
S3method(AIC,HMmdl)
S3method(AIC,MSARmdl)
S3method(AIC,MSVARmdl)
S3method(AIC,Nmdl)
S3method(AIC,VARmdl)
S3method(BIC,ARmdl)
S3method(BIC,HMmdl)
S3method(BIC,MSARmdl)
S3method(BIC,MSVARmdl)
S3method(BIC,Nmdl)
S3method(BIC,VARmdl)
S3method(coef,ARmdl)
S3method(coef,HMmdl)
S3method(coef,MSARmdl)
S3method(coef,MSVARmdl)
S3method(coef,Nmdl)
S3method(coef,VARmdl)
S3method(fitted,ARmdl)
S3method(fitted,HMmdl)
S3method(fitted,MSARmdl)
S3method(fitted,MSVARmdl)
S3method(fitted,Nmdl)
S3method(fitted,VARmdl)
S3method(getHessian,ARmdl)
S3method(getHessian,HMmdl)
S3method(getHessian,MSARmdl)
S3method(getHessian,MSVARmdl)
S3method(getHessian,Nmdl)
S3method(getHessian,VARmdl)
S3method(logLik,ARmdl)
S3method(logLik,HMmdl)
S3method(logLik,MSARmdl)
S3method(logLik,MSVARmdl)
S3method(logLik,Nmdl)
S3method(logLik,VARmdl)
S3method(nobs,ARmdl)
S3method(nobs,HMmdl)
S3method(nobs,MSARmdl)
S3method(nobs,MSVARmdl)
S3method(nobs,Nmdl)
S3method(nobs,VARmdl)
S3method(plot,ARmdl)
S3method(plot,HMmdl)
S3method(plot,MSARmdl)
S3method(plot,MSVARmdl)
S3method(plot,Nmdl)
S3method(plot,VARmdl)
S3method(plot,simuAR)
S3method(plot,simuARX)
S3method(plot,simuHMM)
S3method(plot,simuMSAR)
S3method(plot,simuMSARX)
S3method(plot,simuMSVAR)
S3method(plot,simuMSVARX)
S3method(plot,simuNorm)
S3method(plot,simuVAR)
S3method(plot,simuVARX)
S3method(predict,ARmdl)
S3method(predict,HMmdl)
S3method(predict,MSARmdl)
S3method(predict,MSVARmdl)
S3method(predict,Nmdl)
S3method(predict,VARmdl)
S3method(print,ARmdl)
S3method(print,BootLRTest)
S3method(print,CHPTest)
S3method(print,DLMCTest)
S3method(print,DLMMCTest)
S3method(print,HLRTest)
S3method(print,HMmdl)
S3method(print,LMCLRTest)
S3method(print,MMCLRTest)
S3method(print,MSARmdl)
S3method(print,MSVARmdl)
S3method(print,Nmdl)
S3method(print,VARmdl)
S3method(residuals,ARmdl)
S3method(residuals,HMmdl)
S3method(residuals,MSARmdl)
S3method(residuals,MSVARmdl)
S3method(residuals,Nmdl)
S3method(residuals,VARmdl)
S3method(summary,ARmdl)
S3method(summary,BootLRTest)
S3method(summary,CHPTest)
S3method(summary,DLMCTest)
S3method(summary,DLMMCTest)
S3method(summary,HLRTest)
S3method(summary,HMmdl)
S3method(summary,LMCLRTest)
S3method(summary,MMCLRTest)
S3method(summary,MSARmdl)
S3method(summary,MSVARmdl)
S3method(summary,Nmdl)
S3method(summary,VARmdl)
export(ARXmdl)
export(ARmdl)
export(CHPTest)
export(CHPbootCV)
export(DLMCTest)
export(DLMMCTest)
export(DLMMC_bounds)
export(DLMMCpval_fun)
export(DLMMCpval_fun_min)
export(EMaximization_HMmdl)
export(EMaximization_MSARXmdl)
export(EMaximization_MSARmdl)
export(EMaximization_MSVARXmdl)
export(EMaximization_MSVARmdl)
export(EMiter_HMmdl)
export(EMiter_MSARXmdl)
export(EMiter_MSARmdl)
export(EMiter_MSVARXmdl)
export(EMiter_MSVARmdl)
export(ExpectationM_HMmdl)
export(ExpectationM_MSARXmdl)
export(ExpectationM_MSARmdl)
export(ExpectationM_MSVARXmdl)
export(ExpectationM_MSVARmdl)
export(HLRTest)
export(HLRparamSearch)
export(HMmdl)
export(HMmdl_em)
export(HMmdl_mle)
export(LMCLRTest)
export(LR_samp_dist)
export(LR_samp_dist_par)
export(MCpval)
export(MMCLRTest)
export(MMCLRpval_fun)
export(MMCLRpval_fun_min)
export(MMC_bounds)
export(MSARXmdl)
export(MSARXmdl_em)
export(MSARmdl)
export(MSARmdl_em)
export(MSARmdl_mle)
export(MSVARXmdl)
export(MSVARXmdl_em)
export(MSVARmdl)
export(MSVARmdl_em)
export(MSVARmdl_mle)
export(Nmdl)
export(VARXmdl)
export(VARmdl)
export(approxDistDL)
export(approx_dist_loop)
export(arP)
export(argrid_MSARmdl)
export(argrid_MSVARmdl)
export(calcResid_MSARXmdl)
export(calcResid_MSARmdl)
export(calcResid_MSVARXmdl)
export(calcResid_MSVARmdl)
export(calc_DLmoments)
export(calc_mu2t)
export(calc_mu2t_mv)
export(chpDmat)
export(chpStat)
export(clike)
export(combine_stat)
export(companionMat)
export(compu_tstat)
export(cov2corr)
export(covar_unvech)
export(covar_vech)
export(dmclike)
export(estimMdl)
export(getHessian)
export(initVals_HMmdl)
export(initVals_MSARXmdl)
export(initVals_MSARmdl)
export(initVals_MSVARXmdl)
export(initVals_MSVARmdl)
export(interMSARmdl)
export(interMSVARmdl)
export(limP)
export(logLike_ARXmdl)
export(logLike_ARmdl)
export(logLike_HMmdl)
export(logLike_HMmdl_min)
export(logLike_MSARXmdl)
export(logLike_MSARXmdl_min)
export(logLike_MSARmdl)
export(logLike_MSARmdl_min)
export(logLike_MSVARXmdl)
export(logLike_MSVARXmdl_min)
export(logLike_MSVARmdl)
export(logLike_MSVARmdl_min)
export(logLike_Nmdl)
export(logLike_VARXmdl)
export(logLike_VARmdl)
export(marklike)
export(mclike)
export(mdledit)
export(paramList_MSARXmdl)
export(paramList_MSARmdl)
export(paramList_MSVARXmdl)
export(paramList_MSVARmdl)
export(randP)
export(randSN)
export(sim_DLmoments)
export(simuAR)
export(simuARX)
export(simuARX_cpp)
export(simuAR_cpp)
export(simuHMM)
export(simuHMM_cpp)
export(simuMSAR)
export(simuMSARX)
export(simuMSARX_cpp)
export(simuMSAR_cpp)
export(simuMSVAR)
export(simuMSVARX)
export(simuMSVARX_cpp)
export(simuMSVAR_cpp)
export(simuMdl)
export(simuNorm)
export(simuNorm_cpp)
export(simuVAR)
export(simuVARX)
export(simuVARX_cpp)
export(simuVAR_cpp)
export(thetaSE)
export(ts_lagged)
import(stats)
importFrom(Rcpp,sourceCpp)
useDynLib(MSTest, .registration = TRUE)
